@@ -1,3 +1,4 @@
+import abc
 from typing import Optional
 
 
@@ -10,7 +11,7 @@ class PagingOptions:
         self.offset = offset
 
 
-class Paginator:
+class PageResolver:
     _page_size: int
     _start_page: int
 
@@ -20,3 +21,9 @@ class Paginator:
 
     def get_page(self, page_number: int) -> PagingOptions:
         return PagingOptions(limit=self._page_size, offset=(page_number - self._start_page) * self._page_size)
+
+
+class PagingOptionsConverterInterface(abc.ABC):
+    @abc.abstractmethod
+    def convert(self, order: PagingOptions) -> PagingOptions:
+        raise NotImplementedError()
