@@ -1,4 +1,4 @@
-from typing import List, TypeVar, Generic, Optional, Iterable, Type
+from typing import List, TypeVar, Generic, Optional, Type
 import abc
 
 from abstractrepo.exceptions import ItemNotFoundException
@@ -20,7 +20,7 @@ class CrudRepositoryInterface(abc.ABC, Generic[TModel, TIdValueType, TCreateSche
         filter_spec: Optional[SpecificationInterface[TModel, bool]] = None,
         order_options: Optional[OrderOptions] = None,
         paging_options: Optional[PagingOptions] = None,
-    ) -> Iterable[TModel]:
+    ) -> List[TModel]:
         raise NotImplementedError()
 
     @abc.abstractmethod
@@ -60,15 +60,15 @@ class ListBasedCrudRepository(
 ):
     _db: List[TModel]
 
-    def __init__(self):
-        self._db = []
+    def __init__(self, items: Optional[List[TModel]] = None):
+        self._db = items.copy() if items is not None else []
 
     def get_collection(
         self,
         filter_spec: Optional[SpecificationInterface[TModel, bool]] = None,
         order_options: Optional[OrderOptions] = None,
         paging_options: Optional[PagingOptions] = None,
-    ) -> Iterable[TModel]:
+    ) -> List[TModel]:
         result = self._db.copy()
         result = self._apply_filter(result, filter_spec)
         result = self._apply_order(result, order_options)
@@ -135,7 +135,7 @@ class ListBasedCrudRepository(
             return items
 
         def get_none_key(order_option: OrderOption, value_is_none: bool) -> bool:
-            if int(order_option.nones_order == NonesOrder.FIRST) ^ int(order_option.direction == OrderDirection.DESC):
+            if int(order_option.nones == NonesOrder.FIRST) ^ int(order_option.direction == OrderDirection.DESC):
                 return not value_is_none
             else:
                 return value_is_none
